@@ -13,9 +13,13 @@ def osascript(applescript_or_file,flags=None):
     else:
         flags=""
     if exists(applescript_or_file):
-        return run("osascript %s %s" % (flags,applescript_or_file)).std_out
+        r=run("osascript %s %s" % (flags,applescript_or_file))
     else:
-        return run("osascript %s" % flags,applescript_or_file).std_out
+        r=run("osascript %s" % flags,applescript_or_file)
+    if r.status_code==0:
+        return r.std_out[:-1]
+    else:
+        raise Exception(r.std_err)
 
 def sudo(command):
     """do shell "%s" with administrator privileges
